#ifndef PCOMM_H_
#define PCOMM_H_
/* 
   Copyright (C) 1999 PolyWog and Javaman for Ghetto.Org
   This file is part of the PCR-1000 API Library.

   The PCR-1000 API Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   The PCR-1000 API Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the PCR-1000 API Library; see the file LICENSE.  If not,
   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  
 */

/*
 *  This file declares PCOMM.
 *  PCOMM is the serial i/o object. It facilitates the reading and
 *  writing to the serial socket(s).
 */

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <sys/termios.h>
#include <stdio.h>
#include <unistd.h>
#include <sys/time.h>
#include <stdlib.h>

#include "pcrdef.h"

#define BAUDRATE B9600
#define PCRDEV "/dev/ttyS0"
#define _POSIX_SOURCE 1 /* POSIX compliant source */

typedef int size_pc;    /* i/o count confirmation */

class PComm {
    public:
        PComm(char *, tcflag_t baudRate=B9600, const char *name=0);
        ~PComm();

        bool PCOpen(const char *pcrDev=PCRDEV, tcflag_t baudRate=B9600);
        void PCClose();

        size_pc PCTell(char *);
        size_pc PCAsk(char *);
        size_pc PCHear(char *);
	size_pc PCRawWrite(char *);
	size_pc PCRawRead(char *);

    private:
     size_pc Write(char *);
     size_pc Read(char *);
	
     void 	resetCall();
     void	countCall();
     int 	callCount;
     char   callBuf[256];

     struct  timeval *timeOut;  /* for select to time out */
     fd_set  *FDSet;	        /* socket set for select() */
	 int     retVal;            /* return value for select() */
     struct  termios *oldtio;   /* holds original settings for port */
     struct  termios *newtio;   /* settings to be initiated */
     int     fd;                /* file descriptor for pcrDev */
	 char    pcrDevice[256];	/* device name */
	 tcflag_t pcrSpeed;	        /* baud rate */

     bool errRead;           /* was there an error reading? */
     bool errWrite;          /* was there an error writing? */
     char askBuf[256];      /* buffer for sending data */
     char hearBuf[256];      /* buffer for receiving data */
     char writeBuf[256];     /* write buffer  */
     char readBuf[256];      /* read buffer   */
     char int_name[256];     /* internal name */
     size_pc writeCtr;       /* send bytecount */
     size_pc readCtr;        /* recv bytecount */
	 size_pc askCtr;         /* ask bbytecount */
     size_pc tellCtr;        /* tell bytecount */
     size_pc hearCtr;        /* hear bytecount */
};


#endif /* PCOMM_H_ */
